@@ -1,4 +1,3 @@
-
 # flake8: noqa
 
 # Import all APIs into this package.
@@ -15,7 +14,7 @@
 
 # Import APIs into API package:
 from openapi_client.api.companies_api import CompaniesApi
-from openapi_client.api.machinecounter_api import MachinecounterApi
+from openapi_client.api.machinecounterreadings_api import MachinecounterreadingsApi
 from openapi_client.api.machines_api import MachinesApi
 from openapi_client.api.schema_api import SchemaApi
 from openapi_client.api.states_api import StatesApi
